# -*- coding: utf-8 -*-

import numpy as np
from scipy.io import loadmat as ldmat
from scipy.interpolate import InterpolatedUnivariateSpline as interp1d
import matplotlib.pyplot as plt

# Lectura de datos de Matlab
Data = ldmat('T130_6_1.mat', struct_as_record=False,
                   squeeze_me=True)

# Señal
signal_i = Data['ScopeData'].signals[0].values
eta = -signal_i + np.mean(signal_i)
t = np.linspace(0, 600, len(eta))

# Limpio la señal de fallos de lectura
maskdf = abs(np.diff(eta)) < 4
maskdf = np.append(maskdf, True)
maskf = abs(eta) < abs(np.mean(eta) + 5*np.std(eta))
mask = np.where((maskdf == 1) & (maskf == 1))

e0 = interp1d(t[mask], eta[mask], k=2)
eta_i = e0(t)

plt.figure()
plt.ylim([-250,100])
plt.plot(t, eta)

plt.figure()
plt.ylim([-250,100])
plt.plot(t, eta_i)
